
# q-expansion of newform 363.10.a.e, downloaded from the LMFDB on 01 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 363
weight = 10
poly_data = [109978, -13567, -1947, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0], 1], [[0, 1, 0, 0], 1], [[-9222, -1825, -2, 1], 40], [[-29618, 1345, 42, -1], 40]]

hecke_ring_character_values = None
aps_data = [[-5, 1, 0, 0], [-81, 0, 0, 0], [279, 20, 4, 1], [-2013, -56, -16, -1], [0, 0, 0, 0], [-57353, -1312, -216, 29], [-1312, 6792, -952, 238], [-296574, 6988, -684, -334], [71645, 28224, 456, -1059], [-87952, 86432, 11120, -870], [-1971028, 38932, 18556, -6924], [3415486, 355064, -29208, -1128], [17053578, 282196, -62820, 22120], [-1616648, 205548, 35748, -8872], [-7824157, 576552, 50096, 16531], [10356115, -36844, 53156, 77461], [-33649042, 1922704, -113664, 9026], [-68929795, -724432, -89144, 19291], [53273712, -3057596, -130676, -85356], [66200185, 5213552, 113016, 59361], [-78476338, -470496, 303968, 445888], [-388979155, 2397120, 483432, 137297], [-125469828, 1441364, -654500, -238200], [-348605302, -10396296, -1629400, 117200], [532371008, -2689108, -1167212, -354642], [280995916, 13117424, -2778112, 1331678], [-381861278, -28616036, 115140, 828810], [-707418128, -3028832, -347136, -1156796], [-110033241, 32239104, -933624, -1621939], [-136361426, 10340600, -2171960, 704660], [-1190067835, 31587464, -2547776, 555689], [-439406024, -78421308, -715956, 2199884], [448099856, 65402872, -9589416, 2655614], [-3009904738, -73652028, -3815396, 1330214], [1460168678, -68225432, 1399416, 4682416], [-1782593699, 115958856, 18334720, -4671655], [427458432, 242456520, -16185624, 1416866], [-877017932, -117021304, 20073176, 807536], [153012278, -53382584, 29673224, 257254], [7694850312, -283248968, -27527752, -8475342], [-8424111918, 124689648, 12714944, 5176054], [-13301591760, -310116144, -4210816, 10497674], [-4443368833, 394049296, -62403064, -9536049], [1401557096, 104374280, 25606504, -16337046], [5839953060, 111232008, -36548024, -16036634], [7365630774, -75618516, -39920300, -10873210], [3820422616, 452156284, -80023596, 10324024], [33501708372, -493817364, 72548420, -416380], [-9905946676, 221049568, 62649056, 36082456], [-5955858120, 302748008, -147301048, 12232802], [18674859214, -660936948, 136760484, 13716524], [14395263918, 1751902192, 8026560, -21523210], [6950538224, 1440477848, -184511208, 4926922], [8539337794, 911219216, 69484128, 51072238], [-23404385190, -1292190176, 73899040, -7663960], [13643516720, -1653806264, 3227416, -22757664], [-54026084661, -1671657836, 19655844, 85375509], [-84492449493, 759228360, -83282896, 61525079], [-30410259623, -1647432144, 149854760, -3697225], [64489702824, -659672344, 7796520, -89098970], [9630254584, -1212535652, 23182644, -88546776], [17646963910, 161410048, 254028672, 37618912], [-28774024522, 3145106316, 517964468, -73927962], [123064785033, -3041767840, -244948856, -118695351], [38073517378, 2207553488, 228391344, -9008296], [-14765211287, -4317055892, 168665436, -112862389], [152848520848, -1425173712, 89930800, -161434300], [-148241357294, 1450009696, -202729344, 45353756], [-83638913240, 5377191900, -311689772, -42826932], [88211623667, 3909155712, -546113368, -16725823], [210313306966, -2414061232, 381780240, 130770660], [-268965520946, -7516136944, 167346720, 4504310], [105870419816, -7191774724, -974156396, 13212584], [241211831451, 4488585904, -476163400, 104529185], [445366446660, -362979264, 515386752, 180893992], [138398372673, -10625025040, -1527382472, -23698567], [-214959103465, 3695077476, -696998796, 173036689], [-304171925276, -5023662352, -114751424, -501481674], [-530601061100, 2437494984, -1042149720, -249517430], [204885621896, -25391386728, 1121174424, -217113686], [140024631090, -4289957664, 18732816, -105537754], [70075151286, 4036371656, -1700680168, 656674992], [177744820700, -20195604264, -763444760, -494947740], [-238210074098, 14257128736, 1717461824, -519319476], [-533363042951, 10602377952, 147784104, 466170349], [-8562055294, 12632632584, 376495048, -776129642], [-375147579852, -8304205488, 570622528, -1323592382], [-154624947364, 23007249968, 1414731072, 992920862], [89840342162, 6194995640, 3919995144, -320868556], [100958636038, -13670498596, -3493710364, 933457286], [454890459872, 10644448088, -2548148568, 1173009932], [-34719008368, -24010247336, -1071674488, 1105112792], [-1079693306582, 11705907468, -2417726828, -736543638], [290209296004, 7060938136, -2937829816, -1187284856], [128311032384, -12636660672, 32090720, 1256536740], [-539425878050, 19556231128, -4643672200, -903592850], [289183189451, 47576040788, -4290630044, -1023118859], [-769353263952, -2684986944, 978753904, 1133580734], [-1452959966828, -14460288900, 4197066932, -1190905148], [486525534083, -12975018640, -4264465992, -609701447], [57688588186, 30172870748, -1579658108, 2438684562], [838307779638, -32221810696, -424982040, -2721525240], [433650287904, -59276862424, 4882893528, 1378980948], [-1365262991800, -6142565496, 1064463688, 477973998], [787694672286, 61465406492, 602430756, -1084155874], [1750561138680, -36142236756, -7509176748, 253033542], [138429142738, -19225125800, 511949880, -2519092570], [-1441921066776, 44746487576, -3484003848, 1554332702], [3498298954785, 26921365400, 4747545136, 46458961], [1388597244494, -23245831560, 2168327400, -1703143960], [1474997318413, -23297889840, 5080593048, 1836014193], [-1017048654315, 1400082736, 10399923656, 667978171], [2518424036714, -63715100888, 6205859064, 672659784], [-1805037559400, 72577042268, 2631948756, 3003640076], [-1082521807820, -5655941668, -7658354796, -1248750236], [-49848588628, 121839014592, 11794625744, -3620815126], [1340020200236, 64703159692, 9540315588, -2763347752], [-2396067609467, -56825494824, -3197687792, 216893253], [1574321331317, -134522079876, -8303484500, -621297905], [46542152344, 127036054232, 11378641832, -303874308], [-144599851376, -4490093144, -7273581752, 3959924698], [1159765728936, 6971041536, 13709564048, 2609936138], [-2327352314576, -27669463536, 7069517056, 2327574706], [-199250173402, 6976269560, -3568022664, -4203494174], [-3927629535448, 24481685716, -3157498692, 3421752548], [8201221224714, 108847148688, 1763698192, -2890241028], [3199016618864, -41243927800, -11921420568, -1003093958], [-4478833401351, -140247588752, -10408337736, 6150675209], [1387913907770, -212766276132, -10581706876, -3589167766], [3164596298327, 246919849184, -19729661144, 5853631261], [1061351267964, 1313010396, 8495858772, 6050946052], [-867017326426, -31246514216, -27805326600, 6580807550], [-9453277220532, -22705803812, -974535404, -924893164], [1416783758034, -52687637904, 26903323696, -4688339684], [3284599589168, -216152818856, -12494677000, -2940520250], [2300097376840, 232319909608, 19251436168, -6969312422], [4277942872747, 279458084580, -32093397548, 2108337517], [4404112976568, 209949807780, -8396062900, -11442869040], [-1997251445029, -200010747580, -19000868748, -2189367443], [-805046864898, -15140969844, -9844812700, -10163933900], [7151633259932, -436453021252, -27419836684, -3594518044], [4648899551744, 288418024680, -31224827320, 5365923490], [774982232932, -2642171236, 4083902228, 8428158988], [11680019553616, 344891074028, 10632232516, -10133529084], [9099776252830, -217472809136, 31253911536, -1309188544], [6835468511903, 233680713472, 11195800024, -19371139281], [-8463552661999, -260124217280, -4432108456, -2824202521], [-5338990680914, -157209246132, -53703124444, 9773292196], [-4718072031100, -189149177568, -583436512, -30687623512], [1847012705951, 120006588824, 39558665248, -5693586617], [-21487510618605, 22994317856, 9559442440, -11107341855], [7718474234422, 413042467728, 67166549776, -6567542724], [5385676770860, 124425218972, -38323605964, 16076615296], [5340094774914, -186659803480, 6171722824, 18024645274], [-5307374841124, -155653950100, 31359759908, -2187406512], [-12912034061603, -212979313888, -39066692248, -1755260723], [-3390704114553, -490112338640, 27857136584, 1076585579], [-1825960195132, 104792567912, -88618303096, 9321233754], [2692370587102, 398314715896, -28745029016, 11115558904], [6139299127676, 924501726104, -25520172424, -6883684074], [-7968202584944, -490330081384, -123331546584, 5316196836], [4210884230862, -482450525956, -16811003980, -46363873820], [2328229399649, -117495958760, -36619605104, -7284199379], [8359009061342, -428755910528, 12214573264, -18744852446], [-14385192165920, 282744506352, 6548568128, -18915041322], [6879788508409, 254129140272, 101424847736, -16367177079], [15879903158972, 131022939556, -32225881428, -15249694508], [-12338643396129, 72022363792, -60666278664, -7322605419], [-16755859368916, 4075045408, 30597341648, 15720370118], [3162669817921, -50881322212, -10806911956, -24281585741], [5083259522516, -295992673940, -67250973916, -48627124336], [816115764792, 678187349216, -87873502160, 20967974650], [3209189707822, 896496263696, -20854561248, -19895847818], [18278659393534, -211792941032, 58713038216, 31402331136], [14188987603624, 1114445778092, -20749522524, 12770900696], [14661859839934, 717902577168, -10268376688, 41919918572], [-7084727969182, 74182626244, -106215560580, 14411436370], [11527099608573, 492874278172, 646597772, -46480099873], [27241131944187, -455434741992, 20371104288, -5198991257], [-18068318357717, 259451444864, -43730671384, -16911144039], [-23736585268888, 1076174237580, -84621879932, -12317274112], [15837794109840, 422537182540, -131133731996, 44345727764], [-15725764625342, -85830243416, -209942290024, 2641775996], [-27464211599138, 32043105908, -18073731364, -1678644524], [51736627837717, 451916282824, -24355360032, -16694256827], [-25143751844579, -616466645252, -206616141652, 20957978303], [-26012076899615, -441036021584, -61488584408, -10884094713], [-28298599259292, 222248403380, 46529175100, 77239272240], [31447738752000, -1693687010744, -72724737944, -15846447454], [24368273274492, 125718277768, 166316011768, 19783557428], [-17294711649444, 1926780760372, -19403883700, 4568316890], [-16375173015932, -832258548716, -24366615780, -19795350120], [-34209665138620, 11237592296, -277452438856, -34866092616], [-1512321206357, 789830044820, -135490353180, 18942727005], [5438501834608, 577529575664, 54624458608, 86735195348], [-18745398665786, 881698655000, 62996716136, 44702717596], [2885601054106, -700337241152, 29198627360, 43031179260], [16262042430596, -373374098456, 152664520808, 51219980438], [55238961005646, 921895885572, -84707147572, -31781566292], [-81975595324840, 1816688132384, 93966067424, 39178355344], [40912075461722, 11022067168, -76583173376, 53461650284], [-55726669897193, 24626291800, 9978847104, -4784348981], [58087308598648, -2790904389424, 48015398848, -49906271662], [-47539535102550, 646323816000, -189889017120, 14626627220], [-49082449744510, 976012131096, -202662570952, -65660181602], [28526187153701, 532040517420, -33267435396, 42048203159], [-53153961670210, -2436579113108, 217256337236, -76241133554], [12950360679084, 1309752407668, 242162903164, -6058222256], [63907125906532, -1170627151992, 139582236840, -17770468390], [-8699981763244, -842315910620, -256595262836, -30177688176], [-45506241366380, -1307473356968, 11578669752, -31315052138], [-30474411257107, -179261666324, -112964484228, 109950347967], [67562827293108, 636567351948, 202645952804, -14136677756], [-22650694338500, -3518026374136, 62128229336, 80065962656], [21827096035422, -74256947288, -221967881432, -29099741402], [-6956613670496, -1120392724404, -77677367116, -14391987466], [-242181812827, 386668426872, -202210009008, 26498768417], [-17073708611656, -129466167384, 17694996008, -53523467122], [36817235300285, 1673096133424, -140128134312, 59855225013], [-19429321144275, 1795205155020, -50202772900, 76896049255], [12196005176525, -1973358065504, 51972495512, 114775102587], [19095938563973, -1227445584, -301641090504, -221779278959], [19398557586512, 3003474642192, -409099909472, 67684964598], [130041569700776, 458733924764, 335601088756, 128852449176], [130433039123180, 2555582169776, -287883127280, 64266658000], [81773950849615, 1964399501776, -211447233480, 47179742165], [-65271026245602, 629918806104, 228065665832, -36566120468], [-53824509802893, 2341809619712, -600740417480, -158146736085], [26692404940485, -2658154365800, 189825912560, -57028229095], [110718090572364, -1778729505048, 504776995832, -26016674928], [68732515607846, -4141813803712, -335451382784, 7682181176], [160240842953632, -4149728472556, 172582392604, -59674751936], [-50154225413685, -2069881875640, -7171772944, -30223088129], [-77133922129196, -124977427384, 311043635560, 151747930890], [-223243197349820, 1685566858696, 157131085720, 12884804800], [-89745785516780, -5011977061568, -201432434592, 77206079748], [91190538074650, 6498669596432, 245259385456, -173645442184], [35669630856686, 212353807392, -226764716384, 72950069256], [-199454851763010, 708930493512, 90350111912, -19167963238], [80085528891455, -4923225450280, -166327700320, -104193911825], [103261578126912, 1331598243384, -497964433336, 30919146764], [11966320006880, -6910850727020, 370475719708, 88547358768], [62818573812180, 727170843252, 620865966236, 47344142356], [62038706427220, 5774508464392, 172159524168, -69039085082], [-78190767860136, 2310709725576, 481690450120, 31974087550], [48499961857818, 946833787912, 9636829224, 246743194514], [-62140168295010, -4316455244412, 247257204124, -20341904426], [-190018189979992, -6745013352672, 58518566592, 244150168092], [128414326479506, -6266874148964, 286171265860, -35399909950], [-83584431441430, 3093312953224, 891480302184, -224901380086], [-96042118773619, -1649122024560, -184719709528, -241065719693], [6164255062166, -1300009153476, -533032322636, -144012620276], [268506281622079, -2543693865440, -2464482952, -40788977257], [132645566354160, -2021987941556, -556418832588, 33793263142], [-8076082899638, 1466241324888, 67782898984, 282268626844], [60478848315100, -824212187964, -237763949396, 71071529784], [46598459383478, -4963054490096, -71441359824, 71460258016], [33826140690148, 4097943710148, 875160226572, -45257045428], [77415586120713, -6225461254228, 315047271004, -5194449981], [-150998701587996, 2102258853736, 30914539432, 42166974222], [2563540197347, -2447233636416, 97665577624, 453851997119], [-61652331925956, -3514996452572, 500474262412, -282872203328], [-36402499506373, -529033976720, 48075177400, -49677773655], [45231252491075, -2029361401168, 822300289208, 223266105873], [-139932866372552, 9944463768352, -498293642928, -69605106938], [80599304847312, -9842582571044, -1260811384044, 100675389396], [34057150310265, 6679309681116, 643245367404, -191957018301], [166445944098714, -9916285298448, -182873936496, 17893845624], [139773548819934, -5684389038820, -445852304540, -338440877210], [188455288083088, 2744759771792, -635751089152, 115385451538], [15699774595808, -2910816893080, -134149294648, -512729152558], [112034973494824, 9563800775020, 218204780356, -332394477084], [137158888652324, 565416934116, 45685453916, 364409650986], [-211202823432515, 789374145024, -871717516440, -192442405095], [-134913355508498, -8778396764712, -487486930680, 320962669320], [168199562431890, 5617826545196, -1231761438412, 368039043058], [-182642205523024, 8178414479432, 1383370216568, -85933280052], [305589985941809, -5165727310928, 380574231272, -123840438513], [-2211697627798, 6898092195056, -1820888889744, 162283592356], [-83131015900412, -8937228604648, -2008982617016, 162293760104], [138126721162460, -5453986344824, -92609426824, 206103972036], [135142428751818, 6403833385036, -1173097006380, 82885457050], [-80167449626022, 8561764074512, -164634823168, 584983489602], [-303762584517325, -5299752580464, 429400329496, -94711359479], [252713103868558, 13370323913556, 1400579546380, -372232518210], [-217491505382887, -15045405243400, 340927987920, 196546285265], [2764337544296, -11131681865908, 805387568692, 349133994502], [-190645836337396, 5105846416936, 709204223848, 515497630238], [-180114981006942, -11453745718940, -730326752996, -376980885886], [-178087723749032, -6375319458072, 911443857768, 391312754638], [247266936646539, 394263236724, 1616318215300, 480115095325], [-254826444339402, -5633764379296, -935604486928, -138417014078], [-199315389235408, -15206594478168, -1062980907480, 284696606110], [158442950698408, -2678078656480, 659430425856, 481494774276], [-403912500966925, -1429876554480, -1599682994344, -346739511919], [-95816419381578, -8325027309184, -1783509694400, 686737229800], [-184765553421930, -19701214678516, 106357991988, 210151727918], [-94589501747985, -6080046616604, 621726430964, -826891397951], [-189002540088392, -15048531837596, 1161534304300, -849144327300], [-46891799334256, 1379597893588, 305082571100, 313433725280], [27920310232864, -3198521292008, -1349399685608, 63442777962], [290871787475430, -2266599064, -146344018376, -490654157736], [10880605109263, -6460226966504, 555157864960, 879509589155], [39016487809504, 20300148792216, -1593271651992, 141412702908], [-169277408122200, 20519823045148, 2382292115540, 235071787940], [-107588009827106, 19831999887472, 683239879600, -21951075860], [-97662311181608, -8767207305584, -182296975408, 153231806132], [2173884405462, -20547909354592, -926220479456, -2057457336], [-624962189770609, -13214437822728, 1650718203776, -243060231169], [78351202448711, -625376550336, 947244983752, -592963890963], [191115564882674, 12317467024128, -789359667952, 183095381498], [-838801784584887, 1867232447660, 543038639196, 781404447731], [-535708551365334, -922407017148, 1789193005996, -759425660224], [-363535623708536, 10289711410376, 1056414777464, -236622806676], [210398717601124, -20514668022240, 703605264128, -206779857852], [280913983869926, 6413121287008, -1671413890464, 1167317421016], [177646653067156, 588559600200, -1822359070056, -1144315066016], [76406301548852, 11688426331696, 1419307159984, 173214089764], [-805733703805622, 16235910117440, 1754224095104, 163358576024], [331583691858862, 3927238539780, -1405613248564, -237203270324], [-823975954349758, -5801393216292, 1564637356804, 357855109394], [-35869544723032, -4910829387500, -2688151263860, -29886293730], [-423102504233302, 12744411439176, -2439899994632, -362678572052], [956372185831926, 11288204337852, -1779327053884, 1038808594446], [-559949825673480, -9422082337928, 1031411325912, 120457423942], [-254970911732712, -5384816505596, 3789288840860, -775646309770], [326126398835868, 18240988099044, -246868083380, 906285259520], [211925342178768, -22903625896192, 1377652836960, -968671623780], [-805354541721638, 865630116912, -1749228052256, 216654573874], [-1020016408372108, 4333785144296, -2839230806936, -679340903946], [604665885514533, 5119164620720, 1986085682248, 1246300875563], [128953483965583, 14874052063876, -1245412445484, 1151934086401], [-732782450488357, -19297638916272, 1862746083528, -193233154657], [-612948284313860, 26868033801328, 1894032958480, 695813979800], [-414518965644888, 31496925884580, 2098672990988, 270331550488], [503747552081600, 14562726736296, 1969789424600, -511912804540], [-244690572273540, 4359415451448, -2071019285096, 53851461054], [211186147669728, 8360295959304, 350712218376, -173294247274], [-848127154042110, -26029495096560, -1906888001168, -323370050088], [-732011201522731, -12475464571464, -801967226416, -646647122391], [-152191967153752, 22954271240992, 510494699696, 1121436963186], [106598713156416, 5469700007216, 1458516775296, -695395423994], [-285401606656678, 7297256088976, 109445459024, -637954726556], [631535218740884, 45402377831228, 1536127985012, -1156675737028], [1089318119223267, -1385350984188, -1308752075724, -1127620224979], [-492730020503636, 21793897096324, 3090216219372, -1027405350408], [-666078624626316, 30382119772168, 495840810504, 989493773214], [-17121054776028, 47182993053056, -4584166182464, 815071972376], [-954118904363986, -8776616439984, 4932029091616, -2189929686114], [1139643092761331, 10302439615668, -2798231290620, 1462016976805], [-752892230476936, 22434517895420, -2975566530348, 619581846072], [-820156110920858, 40017757339152, -2660798899184, 934414465756], [-1962104190234581, -5513446633004, -8603279004, -1037366116139], [-272758785116675, -12655328331520, 2824971663272, 485390670097], [-520886364357167, 31057955807232, -2935298648552, -889983592377], [-304215747668306, -7856100495884, 1892551551068, 256798407668], [119893553041705, -16722612585600, 4641296339176, -1046008242359], [-405455412163516, -2607446591072, -1608475267040, -640793203080], [1365831894053446, -5296031601348, 506669219316, -80073217644], [2014679743339743, 8498372909568, -109884703592, -1076342938697], [786484307905093, -7570427092784, -5658044751832, 234225668763], [-360762811895128, 53951028855368, 2509322666312, -822793563738], [-1107223614560643, 63178426084744, 1485928558240, 1027710167125], [267826292720800, -43039146849824, -2951631958208, -799004331148], [-660705493076424, -31888961677916, 2217943642220, -1412877676020], [-1470269337208846, -6385680357072, -2176578884528, -1159212859928], [-1537358865325242, 22947516724608, -3934644494016, -857807965416], [145842677423677, 37905709595816, 802829763488, -2063779305367], [33995272287996, 39433384123000, 1689734355864, 1621532348534], [640079402498902, -11113919933624, -3417832768024, -49864357774], [1202115612125540, 27540659327808, 606641435392, -50569197768], [1593689019592900, 51452372734504, -4032816064680, 868765451940], [1458621621774072, -20430445888072, -4564359026440, -361746001190], [-500562570948891, -19438158017760, -9447945784632, -219502320007], [455991570651458, -30183732702480, -1876914347280, 2219802860420], [-1364824892793408, 49715706178072, 1169358898728, 1050942724708], [2414756527148290, -12715185738232, -3261198513176, 1292637908394], [-617418470200050, 31623329126784, 3365527771520, -2401728073120], [234983882970886, -9782108630500, 6294317486612, -1160045071388], [-377605461157292, -40750043862568, 1709919993912, 877895690022], [1600417240583523, -16595417414156, 110478819780, -1326275239995], [838364530372880, -2429042339624, -2886666328904, 4076272885046], [-686027211731907, -12873109864856, 5992147250144, 1990933771369], [2038930326590740, -47573837936872, -4396720613864, -1071928143774], [-847793241849388, 33126460492244, 1434916207676, 2557508423036], [1396841563284307, 49713376841384, 770731213552, -1166914724293], [-223623362473144, 34167352818556, -2019854518188, -1130307553968], [1815358060516518, 70546054134872, 6548112134600, -2013617189840], [-1898546413047948, -6888592971292, -3878988434388, -3022546101868], [-1859581238051589, -29555661378944, 3834899439544, -1288711155861], [1285749886987420, -8203875009532, 2435432817340, -1430948645270], [-1777924744575463, -23886040515876, 1121758995244, -1090416485861], [-1014543009810266, -77043175429856, 5250465240752, 1944293546242], [658874556530980, -21854665605376, -5144236264384, 1107387636296], [-60295732003913, -17822089790664, 2104119035776, 552495409111], [1452096296290320, 52346201534224, 1655784296704, -2956269274926], [-316237104681557, 42011761970408, 3099395065936, -1399916976369], [1035121077279572, -20428656927096, 4404676929256, 169438495626], [2052209795955016, 33041962042864, -1365364477648, 3269879861532], [-692041271631236, 2709454822112, 2914135916624, -745252830466], [395215293159469, 59891312674624, -1909575370888, 2924294328027], [4279259658464224, -11458109156944, -784111781760, 745372871830], [-610446873413557, -55559946990088, 5416096691072, -1388032157793], [904095884131984, -44326868587728, 2508398977920, -471493268650], [1757904326278330, 4883432585648, 12803746041264, 4055268044804], [-3688114229455533, 28404316574480, 809807864200, 1886063362335], [203842764542642, 67253921318232, 644107587816, -322669736444], [-4399595790197126, -15001349535244, 4748080098364, -1644177751616], [2574732524468976, -49414322605692, 8610610977740, 1196633305860], [906389935448796, -8658822560224, 1517492271328, -2469895485472], [-3704053179149890, -45323391598240, -5551458472800, 946166836640], [-1547864639019614, 6033237054600, -8782562542152, 70994843548], [-701555882071084, 2571432634520, -3528068938104, -1585956014544], [1917499338808810, -30687241184396, -8368537421044, 716751583746], [1630912182737038, 32884085836504, 9202016936904, 1375020796784], [1897072053318037, 26530255244860, -6361700912212, 1570518902423], [227335514661130, -12848358866928, -95999686784, -725667777934], [-2743066400295778, 68134675901580, 302816595572, -320564959738], [2191954017948172, 4761972157336, 4435642049816, -2421924464774], [2435976937243290, 19578803651136, -2833628320432, -1207103229782], [409330243859821, -87325198649108, 2115168872764, -1305479057401], [181605914043109, 15418877681744, -7431644054488, -444307106133], [-373481015061747, -111102307638936, -19467452027008, 2352188255197], [853440250805688, -103640698530664, -1234026360344, -4774567827604], [1177686004843896, 171523163246236, -7376246951580, -2312034620130], [-1664295778751101, 129849269290148, 797061662228, 1622481758493], [2726486364910404, 10856927028416, 1976985099008, -682164090712], [-17697380217554, 11464376157468, -4595156421932, 986337806748], [-922236325386488, 120798254210392, 15191095550504, -1202301750516], [-163720612848920, -20444217390584, 6274488211864, -3105506936056]]
